'' +--------------------------------------------------------------------------+
'' | Cluso's Propeller Operating System - OS module: _VER  --> _VER.CMD       |
'' +--------------------------------------------------------------------------+
'' |  Authors:       (c)2011 by Kwabena W. Agyman (Kye) & J. Moxham (Dr_Acula)|
'' |  Modifications: (c)2012 "Cluso99" (Ray Rodrick)                          |
'' |  License:       MIT License - See end of file for terms of use           |
'' +--------------------------------------------------------------------------+
'' This OS module uses an included module to perform most of the housekeeping.
'' Each module is called from, and returns to, the prop binary "_CMD.CMD"
'' Compile with PropTool + "PreSpin 0.3" by Andy Schenk www.insonix.ch/propeller                             
'' Some OS modules are derived from: 
''      KyeDOS v3 (c) 2011 by Kwabena W. Agyman (Kye) & J. Moxham (Dr_Acula)
'' See the included code for history and acknowledgments.
''
'' RR20120317   This module does......

'#include "__MODULE.spin"        ' include the common code for OS modules 

DAT
_ModuleStr    byte      "=== VER ===",0        'module's name (string)
 
PRI executeCommand(stringPointer) | z,z0,z1,z2,z3,z4

  ifnot(str.stringCompareCI(string("ver"), stringPointer))     '<-- module's name
    PrintStringCR(string("*** Propeller SD card Operating System v0.40 ***"))
    PrintStringCR(string(" Derived from KyeDOS..."))
    PrintStringCR(string("   by Kwabena W. Agyeman & J. Moxham & Cluso99 "))
    PrintStringCR(string("    & acknowledgements to M. Park (Sphinx) etc"))
    crlf

    PrintString(string(" ClockFreq "))
    PrintString(str.integerToDecimal(long[$0],9))
    PrintString(string("Hz, mode $"))
    PrintStringCR(str.integerToHexadecimal(byte[$4],2))

    PrintString(string(" Hardware: "))
    case long[_hub#_hardware] >> 16  'hardware >> 29
      $0001 : PrintString(string("Cluso's "))
      other : PrintString(string("??? "))
    case long[_hub#_hardware]  'hardware >> 29
      $0001_0001 : PrintString(string("RamBlade"))
      $0001_0002 : PrintString(string("TriBlade#2"))
      $0001_0003 : PrintString(string("RamBlade3"))
      other: PrintString(string("???"))
    crlf
    PrintString(string(" SD card on pins "))
    z  := long[_hub#_sdPins]
    z0 :=  z        & $1F
    z1 := (z >>  8) & $1F
    z2 := (z >> 16) & $1F
    z3 := (z >> 24) & $1F
    PrintString(str.integerToDecimal(z0, 2))    
    PrintChar(",")
    PrintString(str.integerToDecimal(z1, 2))    
    PrintChar(",")
    PrintString(str.integerToDecimal(z2, 2))    
    PrintChar(",")
    PrintString(str.integerToDecimal(z3, 2))    
    crlf
    PrintString(string(" Serial  on pins "))
    z  := long[_hub#_sioPins]
    z0 :=  z        & $1F
    z1 := (z >>  8) & $1F
    z2 := (z >> 16) & $1F
    z3 := (z >> 24) & $07
    z4 :=  long[_hub#_sioBaud]
    PrintString(str.integerToDecimal(z0, 2))    
    PrintChar(",")
    PrintString(str.integerToDecimal(z1, 2))    
    PrintString(string(", Mode "))
    PrintString(str.integerToDecimal(z2, 2))    
    PrintString(string(", Baud "))
    PrintString(str.integerToDecimal(z4, 8))    
    PrintString(string(", Cog "))
    PrintString(str.integerToDecimal(z3, 1))    
    crlf
    PrintString(string(" <LF> is "))
    if long[_hub#_OS_BITS] & _hub#_OS_LFmask
      PrintStringCR(string("ON"))
    else
      PrintStringCR(string("OFF"))
    PrintString(string(" Resident Cogs: "))
    repeat z from 0 to 7
      if (byte[_hub#_OS_COGS] >> z) & $01 == 1
        PrintString(str.integerToDecimal(z, 1))
        PrintString(string(" "))
    crlf

    crlf
    
    abort 0

dat                                                   
{{
+------------------------------------------------------------------------------------------------------------------------------+
|                                                   TERMS OF USE: MIT License                                                  |                                                            
+------------------------------------------------------------------------------------------------------------------------------+
|Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation    | 
|files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy,    |
|modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software|
|is furnished to do so, subject to the following conditions:                                                                   |
|                                                                                                                              |
|The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.|
|                                                                                                                              |
|THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE          |
|WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR         |
|COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,   |
|ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                         |
+------------------------------------------------------------------------------------------------------------------------------+
}}